summaryrefslogtreecommitdiffstats
path: root/kmouth/phraselistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmouth/phraselistitem.h')
-rw-r--r--kmouth/phraselistitem.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmouth/phraselistitem.h b/kmouth/phraselistitem.h
index 24d5e49..3afc85b 100644
--- a/kmouth/phraselistitem.h
+++ b/kmouth/phraselistitem.h
@@ -18,17 +18,17 @@
#ifndef PHRASELISTITEM_H
#define PHRASELISTITEM_H
-#include <qlistbox.h>
+#include <tqlistbox.h>
/**
* This class represents a phrase in the list of spoken phrases. It extends
* QListBoxText for providing support for a visible list cursor.
* @author Gunnar Schmi Dt
*/
-class PhraseListItem : public QListBoxText {
+class PhraseListItem : public TQListBoxText {
public:
- PhraseListItem (const QString & text);
+ PhraseListItem (const TQString & text);
~PhraseListItem();
bool drawCursor() const;
@@ -37,7 +37,7 @@ public:
static const int RTTI = 982734;
protected:
- void paint( QPainter * );
+ void paint( TQPainter * );
};
#endif
@@ -18,17 +18,17 @@
/**
* This class represents a phrase in the list of spoken phrases. It extends
- * QListBoxText for providing support for a visible list cursor.
+ * TQListBoxText for providing support for a visible list cursor.
* @author Gunnar Schmi Dt
*/